@@ -108,7 +108,7 @@ class SecretStore:
         try:
 
             param = self.ssm.get_parameters(
-                Name=name,
+                Names=name,
                 WithDecryption=True,
             )
 
